@@ -4,8 +4,8 @@ import configparser
 import importlib
 import copy
 
-from tryp.util.string import camelcaseify
-from tryp.lazy import lazy
+from amino.util.string import camelcaseify
+from amino.lazy import lazy
 
 from golgi.config.errors import (NoSuchSectionError, NoSuchOptionError,
                                  ConfigClientNotYetConnectedError,
